@@ -1,18 +1,14 @@
 package SVN::Class;
 use strict;
 use warnings;
-use base qw( Path::Class Rose::Object );
-use Rose::Object::MakeMethods::Generic (
-    scalar => [qw( svn stdout stderr error error_code verbose debug )] );
+use base qw( Path::Class Class::Accessor::Fast );
+__PACKAGE__->mk_accessors(
+    qw( svn stdout stderr error error_code verbose debug ));
 use Carp;
 use Data::Dump;
 use IPC::Cmd qw( can_run run );
 use SVN::Class::File;
 use SVN::Class::Dir;
-use SVN::Class::Info;
-use Text::ParseWords;
-
-$ENV{LC_ALL} = 'C';    # we expect our responses in ASCII
 
 #$IPC::Cmd::DEBUG   = 1;
 #$IPC::Cmd::VERBOSE = 1;
@@ -22,38 +18,15 @@ unless ( IPC::Cmd->can_capture_buffer ) {
         . "Do you have IPC::Run installed?";
 }
 
-# IPC::Run fails tests because we use built-in shell commands
-# not found in PATH
-$IPC::Cmd::USE_IPC_RUN = 1;
-
 # this trick cribbed from mst's Catalyst::Controller::WrapCGI
 # we alias STDIN and STDOUT since Catalyst (and presumaly other code)
 # might be messing with STDOUT or STDIN
-my $REAL_STDIN  = *STDIN;
-my $REAL_STDOUT = *STDOUT;
-my $REAL_STDERR = *STDERR;
-if ( $ENV{SVN_CLASS_ALIAS_STDOUT} ) {
-    open $REAL_STDIN,  "<&=" . CORE::fileno(*STDIN);
-    open $REAL_STDOUT, ">>&=" . CORE::fileno(*STDOUT);
-    open $REAL_STDERR, ">>&=" . CORE::fileno(*STDERR);
-}
-
-sub _debug_stdin_fh {
-
-    #warn "     stdin fileno = " . CORE::fileno(*STDIN);
-    #warn "real_stdin fileno = " . CORE::fileno($REAL_STDIN);
-}
-
-sub _debug_stdout_fh {
-
-    #warn "     stdout fileno = " . CORE::fileno(*STDOUT);
-    #warn "real_stdout fileno = " . CORE::fileno($REAL_STDOUT);
-}
+open( *REAL_STDIN,  "<&=" . fileno(*STDIN) );
+open( *REAL_STDOUT, ">>&=" . fileno(*STDOUT) );
 
 our @EXPORT    = qw( svn_file svn_dir );
 our @EXPORT_OK = qw( svn_file svn_dir );
-
-our $VERSION = '0.13_03';
+our $VERSION   = '0.01';
 
 =head1 NAME
 
@@ -68,11 +41,13 @@ SVN::Class - manipulate Subversion workspaces with Perl objects
  print {$fh} "hello world\n";
  $fh->close;
  $file->add;
- if ($file->modified) {
+ if ($file->modified)
+ {
     my $rev = $file->commit('the file changed');
     print "$file was committed with revision $rev\n";
  }
- else {
+ else
+ {
     croak "$file was not committed: " . $file->errstr;
  }
  
@@ -125,38 +100,6 @@ are documented here.
 
 =cut
 
-=head2 svn
-
-Path to the svn binary. Defaults to C<svn> and thus relies on environment's
-PATH to find and execute the correct command.
-
-=head2 stdout
-
-Get the stdout from the last svn_run().
-
-=head2 stderr
-
-Get the stderr from the last svn_run().
-
-=head2 error
-
-If the last svn_run() exited with non-zero, error() will return same
-as stderr(). If svn_run() was successful, returns the empty string.
-
-=head2 error_code
-
-Returns the last exit value of svn_run().
-
-=head2 verbose
-
-Get/set a true value to enable IPC output in svn_run().
-
-=head2 debug
-
-Get/set a true value to see debugging output printed on stderr.
-
-=cut
-
 =head2 svn_run( I<cmd>, I<opts>, I<file> )
 
 Execute I<cmd> given I<opts> and I<file> as arguments. This is a wrapper
@@ -171,44 +114,22 @@ stderr, err, errstr, and error_code values in the SVN::Class object.
 
 This method is used internally by all the Subversion commands.
 
-B<NOTE:> In order to standardize the output of Subversion commands into
-a locale that is easily parse-able by other methods that call svn_run()
-internally, all commands are run with C<LC_ALL=C> to make sure
-output is ASCII only.
-
 =cut
 
 sub svn_run {
-    my $self = shift;
-    my $cmd  = shift or croak "svn command required";
-    my $opts = shift || [];
-    my $file = shift || "$self";
-
-    # since $opts may contain whitespace, must pass command as array ref
-    # to IPC::Run
-    my $command
-        = [ $self->svn, $cmd, shellwords( join( ' ', @$opts ) ), $file ];
+    my $self    = shift;
+    my $cmd     = shift or croak "svn command required";
+    my $opts    = shift || [];
+    my $file    = shift || "$self";
+    my $command = join( ' ', $self->svn, $cmd, @$opts, $file );
 
     my @out;
 
-    $self->_debug_stdin_fh;
-    $self->_debug_stdout_fh;
-
     {
-        local *STDIN  = $REAL_STDIN;    # restore the real ones so the filenos
-        local *STDOUT = $REAL_STDOUT;   # are 0 and 1 for the env setup
-        local *STDERR = $REAL_STDERR;
+        local *STDIN  = \*REAL_STDIN;   # restore the real ones so the filenos
+        local *STDOUT = \*REAL_STDOUT;  # are 0 and 1 for the env setup
 
-        my $old = select($REAL_STDOUT);  # in case somebody just calls 'print'
-
-        # Use local signal handler so global handler
-        # does not result in bad values in $? and $!
-        # http://www.perlmonks.org/?node_id=197500
-        # useful for running under Catalyst (e.g.)
-        local $SIG{CHLD} = '';
-
-        $self->_debug_stdin_fh;
-        $self->_debug_stdout_fh;
+        my $old = select(REAL_STDOUT);  # in case somebody just calls 'print'
 
         (@out) = run( command => $command, verbose => $self->verbose );
 
@@ -223,13 +144,8 @@ sub svn_run {
 
     # return code is a little murky as $error_code is often -1
     # which sometimes signals success, while $success is undef.
-    if ( !defined($success) ) {
-        if ( $error_code eq '-1' && !@stderr ) {
-            $success = 1;
-        }
-        else {
-            $success = 0;
-        }
+    if ( !defined($success) && $error_code == -1 && !@stderr ) {
+        $success = 1;
     }
 
     $self->stdout( \@stdout );
@@ -238,7 +154,6 @@ sub svn_run {
     $self->error_code($error_code);
 
     if ( $self->debug || $ENV{PERL_DEBUG} ) {
-        carp "command: $command";
         carp Data::Dump::dump \@out;
         $self->dump;
         carp "success = $success";
@@ -321,14 +236,13 @@ sub commit {
 
     # croak if failure but set error() and error_code()
     # first in case wrapped in eval().
-    my $self    = shift;
+    my $self = shift;
     my $message = shift or croak "commit message required";
-    my $opts    = shift || [];
 
     # must escape any literal '" in the message
     $message =~ s,(['"]),\\$1,g;
 
-    my $ret = $self->svn_run( 'commit', [ "-m \"$message\"", @$opts ] );
+    my $ret = $self->svn_run( 'commit', ["-m \"$message\""] );
 
     # $ret is empty string on success. that's odd.
     if ( defined( $self->{stdout}->[0] )
@@ -351,14 +265,14 @@ sub status {
 
     if ( $self->is_dir ) {
 
-        # find the arg that matches $self
+        # check only first arg to see if it matches self
         if ( defined $self->stdout->[0] ) {
-            for my $line ( @{ $self->stdout } ) {
-                if ( $line =~ m/^(\S)\s+$self$/ ) {
-                    return $1;
-                }
+            if ( $self->stdout->[0] =~ m/^(\S)\s+$self$/ ) {
+                return $1;
+            }
+            else {
+                return 0;
             }
-            return 0;
         }
     }
 
@@ -410,19 +324,6 @@ sub blame {
     shift->svn_run( 'blame', @_ );
 }
 
-=head2 info
-
-Returns SVN::Class::Info instance with information about the current
-object or 0 on failure.
-
-=cut
-
-sub info {
-    my $self = shift;
-    return 0 unless $self->svn_run( 'info', @_ );
-    return SVN::Class::Info->new( $self->stdout );
-}
-
 =head2 dump
 
 Returns a Data::Dump serialization of the object. Useful for debugging.
@@ -435,26 +336,12 @@ sub dump {
 
 =head2 errstr
 
-Returns the contents of error() as a newline-joined string.
+Returnss the contents of error() as a newline-joined string.
 
 =cut
 
 sub errstr {
-    my $self = shift;
-    my $err  = $self->error;
-    return ref($err) ? join( "\n", @$err ) : $err;
-}
-
-=head2 outstr
-
-Returns the contents of stdout() as a newline-joined string.
-
-=cut
-
-sub outstr {
-    my $self = shift;
-    my $out  = $self->stdout;
-    return ( ref($out) ? join( "\n", @$out ) : $out ) . "\n";
+    return join( "\n", shift->error );
 }
 
 1;
@@ -513,6 +400,7 @@ sponsored the development of this software.
 =head1 COPYRIGHT
 
 Copyright 2007 by the Regents of the University of Minnesota.
+All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
